/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Html.xs. Do not edit this file, edit Html.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/html/Html.xs
// Purpose:     XS for Wx::Html*
// Author:      Mattia Barbon
// Modified by:
// Created:     10/03/2001
// RCS-ID:      $Id: Html.xs 3281 2012-05-06 07:25:12Z mdootson $
// Copyright:   (c) 2001-2004, 2006, 2008-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include <wx/html/htmlwin.h>

#undef THIS

#define wxDefaultValidatorPtr (wxValidator*)&wxDefaultValidator

// event macros
#define SEVT( NAME, ARGS )    wxPli_StdEvent( NAME, ARGS )
#define EVT( NAME, ARGS, ID ) wxPli_Event( NAME, ARGS, ID )

// !package: Wx::Event
// !tag:
// !parser: sub { $_[0] =~ m<^\s*S?EVT\(\s*(\w+)\s*\,> }

static wxPliEventDescription evts[] =
{
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
    EVT( EVT_HTML_CELL_CLICKED, 3, wxEVT_COMMAND_HTML_CELL_CLICKED )
    EVT( EVT_HTML_CELL_HOVER, 3, wxEVT_COMMAND_HTML_CELL_HOVER )
    EVT( EVT_HTML_LINK_CLICKED, 3, wxEVT_COMMAND_HTML_LINK_CLICKED )
#endif
    { 0, 0, 0 }
};

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlWindow.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/html/htmlwin.h>
#include <wx/frame.h>
#include "cpp/htmlwindow.h"
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_2dfb8a31_096998
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__HtmlCellEvent_GetCell); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCellEvent_GetCell)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCellEvent *    THIS = (wxHtmlCellEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCellEvent" )
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = THIS->GetCell();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCellEvent_GetPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCellEvent_GetPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCellEvent *    THIS = (wxHtmlCellEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCellEvent" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetPoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCellEvent_GetMouseEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCellEvent_GetMouseEvent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCellEvent *    THIS = (wxHtmlCellEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCellEvent" )
;
	wxMouseEvent *	RETVAL;
    try {
      RETVAL = new wxMouseEvent( THIS->GetMouseEvent() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::MouseEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCellEvent_SetLinkClicked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCellEvent_SetLinkClicked)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, linkclicked");
    {
	wxHtmlCellEvent *    THIS = (wxHtmlCellEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCellEvent" )
;
	bool	linkclicked = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetLinkClicked( linkclicked );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCellEvent_GetLinkClicked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCellEvent_GetLinkClicked)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCellEvent *    THIS = (wxHtmlCellEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCellEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetLinkClicked();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlLinkEvent_GetLinkInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlLinkEvent_GetLinkInfo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlLinkEvent *    THIS = (wxHtmlLinkEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlLinkEvent" )
;
	wxHtmlLinkInfo *	RETVAL;
    try {
      RETVAL = new wxHtmlLinkInfo( THIS->GetLinkInfo() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlLinkInfo" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlLinkInfo_GetEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlLinkInfo_GetEvent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlLinkInfo *    THIS = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlLinkInfo" )
;
	wxMouseEvent *	RETVAL;
    RETVAL = (wxMouseEvent*) THIS->GetEvent();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::MouseEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlLinkInfo_GetHtmlCell); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlLinkInfo_GetHtmlCell)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlLinkInfo *    THIS = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlLinkInfo" )
;
	wxHtmlCell *	RETVAL;
    RETVAL = (wxHtmlCell*) THIS->GetHtmlCell();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlLinkInfo_GetHref); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlLinkInfo_GetHref)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlLinkInfo *    THIS = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlLinkInfo" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetHref();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlLinkInfo_GetTarget); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlLinkInfo_GetTarget)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlLinkInfo *    THIS = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlLinkInfo" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTarget();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxHW_SCROLLBAR_AUTO, name = wxT(\"htmlWindow\")");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlWindow *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHW_SCROLLBAR_AUTO;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxT("htmlWindow");
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPliHtmlWindow( CLASS, parent, id, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_AppendToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_AppendToPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, source");
    {
	wxString	source;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

    WXSTRING_INPUT( source, wxString, ST(1) )
;

	RETVAL = THIS->AppendToPage(source);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedAnchor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetOpenedAnchor();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetOpenedPage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedPageTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_GetOpenedPageTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetOpenedPageTitle();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_GetParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_GetParser)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxHtmlWinParser *	RETVAL;

	RETVAL = THIS->GetParser();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_GetRelatedFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_GetRelatedFrame)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxFrame *	RETVAL;

	RETVAL = THIS->GetRelatedFrame();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_HistoryBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_HistoryBack)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->HistoryBack();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_HistoryCanForward); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_HistoryCanForward)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->HistoryCanForward();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_HistoryCanBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_HistoryCanBack)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->HistoryCanBack();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_HistoryClear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_HistoryClear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->HistoryClear();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_HistoryForward); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_HistoryForward)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->HistoryForward();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_LoadFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxString	filename;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;

	RETVAL = THIS->LoadFile(filename);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_LoadPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_LoadPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, location");
    {
	wxString	location;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

    WXSTRING_INPUT( location, wxString, ST(1) )
;

	RETVAL = THIS->LoadPage(location);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_OnLinkClicked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_OnLinkClicked)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, info");
    {
	wxHtmlLinkInfo*    info = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlLinkInfo" )
;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
    THIS->wxHtmlWindow::OnLinkClicked( *info );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_OnSetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_OnSetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxString	title;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

    WXSTRING_INPUT( title, wxString, ST(1) )
;
    THIS->wxHtmlWindow::OnSetTitle( title );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_ReadCustomization); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_ReadCustomization)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, cfg, path = wxEmptyString");
    {
	wxConfigBase*    cfg = (wxConfigBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ConfigBase" )
;
	wxString	path;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	if (items < 3)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(2) )
;
	}

	THIS->ReadCustomization(cfg, path);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SetBorders); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SetBorders)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, b");
    {
	int	b = (int)SvIV(ST(1))
;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->SetBorders(b);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SetFonts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SetFonts)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, normal_face, fixed_face, sizes");
    {
	wxString	normal_face;
	wxString	fixed_face;
	SV*	sizes = ST(3)
;
    int* array;
    int n = wxPli_av_2_intarray( aTHX_ sizes, &array );
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

    WXSTRING_INPUT( normal_face, wxString, ST(1) )
;

    WXSTRING_INPUT( fixed_face, wxString, ST(2) )
;
    if( n != 7 )
    {
       delete[] array;
       croak( "Specified %d sizes, 7 wanted", n );
    }
    THIS->SetFonts( normal_face, fixed_face, array );
    delete[] array;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SetPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SetPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, source");
    {
	wxString	source;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	bool	RETVAL;

    WXSTRING_INPUT( source, wxString, ST(1) )
;

	RETVAL = THIS->SetPage(source);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_SetRelatedFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SetRelatedFrame)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, frame, format");
    {
	wxFrame*    frame = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Frame" )
;
	wxString	format;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

    WXSTRING_INPUT( format, wxString, ST(2) )
;

	THIS->SetRelatedFrame(frame, format);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SetRelatedStatusBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SetRelatedStatusBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bar");
    {
	int	bar = (int)SvIV(ST(1))
;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->SetRelatedStatusBar(bar);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__HtmlWindow_SelectWord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SelectWord)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->SelectWord(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SelectLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SelectLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->SelectLine(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	THIS->SelectAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWindow_SelectionToText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_SelectionToText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxString	RETVAL;

	RETVAL = THIS->SelectionToText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWindow_ToText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_ToText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;
	wxString	RETVAL;

	RETVAL = THIS->ToText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlWindow_WriteCustomization); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWindow_WriteCustomization)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, cfg, path = wxEmptyString");
    {
	wxConfigBase*    cfg = (wxConfigBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ConfigBase" )
;
	wxString	path;
	wxHtmlWindow *    THIS = (wxHtmlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWindow" )
;

	if (items < 3)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(2) )
;
	}

	THIS->WriteCustomization(cfg, path);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlWindow.xsp' */


/* INCLUDE:  Including 'XS/HtmlHelpController.xs' from 'Html.xs' */

#include <wx/html/helpctrl.h>
#if defined(__WXMSW__)
#if wxPERL_USE_BESTHELP
#include <wx/msw/helpbest.h>
#undef THIS
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__BestHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BestHelpController_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent = NULL, style = wxHF_DEFAULT_STYLE");
    {
	wxWindow*	parent;
	int	style;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBestHelpController *	RETVAL;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}

	if (items < 3)
	    style = wxHF_DEFAULT_STYLE;
	else {
	    style = (int)SvIV(ST(2))
;
	}

	RETVAL = new wxBestHelpController(parent, style);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__BestHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BestHelpController_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBestHelpController *	RETVAL;

	RETVAL = new wxBestHelpController();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#endif
#endif

XS_EUPXS(XS_Wx__HtmlHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, style = wxHF_DEFAULTSTYLE");
    {
	long	style;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlHelpController *	RETVAL;

	if (items < 2)
	    style = wxHF_DEFAULTSTYLE;
	else {
	    style = (long)SvIV(ST(1))
;
	}
    RETVAL = new wxHtmlHelpController( style );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlHelpController_AddBook); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_AddBook)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, book, show_wait");
    {
	wxString	book;
	bool	show_wait = (bool)SvTRUE(ST(2))
;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;
	bool	RETVAL;

    WXSTRING_INPUT( book, wxString, ST(1) )
;

	RETVAL = THIS->AddBook(book, show_wait);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlHelpController_Display); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_Display)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, x");
    {
	wxString	x;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

    WXSTRING_INPUT( x, wxString, ST(1) )
;

	THIS->Display(x);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_DisplayId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_DisplayId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;
    THIS->Display( id );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_DisplayContents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_DisplayContents)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

	THIS->DisplayContents();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_DisplayIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_DisplayIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

	THIS->DisplayIndex();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_KeywordSearch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_KeywordSearch)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, keyword");
    {
	wxString	keyword;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;
	bool	RETVAL;

    WXSTRING_INPUT( keyword, wxString, ST(1) )
;

	RETVAL = THIS->KeywordSearch(keyword);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlHelpController_ReadCustomization); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_ReadCustomization)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, cfg, path = wxEmptyString");
    {
	wxConfigBase*    cfg = (wxConfigBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ConfigBase" )
;
	wxString	path;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

	if (items < 3)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(2) )
;
	}

	THIS->ReadCustomization(cfg, path);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_SetTempDir); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_SetTempDir)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxString	path;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

    WXSTRING_INPUT( path, wxString, ST(1) )
;

	THIS->SetTempDir(path);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_SetTitleFormat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_SetTitleFormat)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, format");
    {
	wxString	format;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

    WXSTRING_INPUT( format, wxString, ST(1) )
;

	THIS->SetTitleFormat(format);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_UseConfig); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_UseConfig)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, config, path = wxEmptyString");
    {
	wxConfigBase*    config = (wxConfigBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ConfigBase" )
;
	wxString	path;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

	if (items < 3)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(2) )
;
	}

	THIS->UseConfig(config, path);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlHelpController_WriteCustomization); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlHelpController_WriteCustomization)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, cfg, path = wxEmptyString");
    {
	wxConfigBase*    cfg = (wxConfigBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ConfigBase" )
;
	wxString	path;
	wxHtmlHelpController *    THIS = (wxHtmlHelpController *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlHelpController" )
;

	if (items < 3)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(2) )
;
	}

	THIS->WriteCustomization(cfg, path);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'Html.xs' from 'XS/HtmlHelpController.xs' */

#if wxPERL_USE_PRINTING_ARCHITECTURE
#define XSubPPtmpAAAE 1


/* INCLUDE:  Including 'XS/HtmlEasyPrinting.xs' from 'Html.xs' */


/* INCLUDE:  Including 'XS/HtmlDCRenderer.xs' from 'XS/HtmlEasyPrinting.xs' */

#include <wx/html/htmprint.h>
#include <wx/dc.h>

XS_EUPXS(XS_Wx__HtmlDCRenderer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlDCRenderer *	RETVAL;

	RETVAL = new wxHtmlDCRenderer();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlDCRenderer" );
    wxPli_thread_sv_register( aTHX_ "Wx::HtmlDCRenderer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::HtmlDCRenderer", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_SetDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_SetDC)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, dc, pixel_scale = 1.0");
    {
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	double	pixel_scale;
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;

	if (items < 3)
	    pixel_scale = 1.0;
	else {
	    pixel_scale = (double)SvNV(ST(2))
;
	}

	THIS->SetDC(dc, pixel_scale);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_SetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_SetSize)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;

	THIS->SetSize(width, height);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_SetHtmlText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_SetHtmlText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, htmlText, basepath = wxEmptyString, isdir = 1");
    {
	wxString	htmlText;
	wxString	basepath;
	bool	isdir;
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;

    WXSTRING_INPUT( htmlText, wxString, ST(1) )
;

	if (items < 3)
	    basepath = wxEmptyString;
	else {
    WXSTRING_INPUT( basepath, wxString, ST(2) )
;
	}

	if (items < 4)
	    isdir = 1;
	else {
	    isdir = (bool)SvTRUE(ST(3))
;
	}

	THIS->SetHtmlText(htmlText, basepath, isdir);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlDCRenderer_SetFonts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_SetFonts)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, normal_face, fixed_face, sizes");
    {
	wxString	normal_face;
	wxString	fixed_face;
	SV*	sizes = ST(3)
;
    int* array;
    int n = wxPli_av_2_intarray( aTHX_ sizes, &array );
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;

    WXSTRING_INPUT( normal_face, wxString, ST(1) )
;

    WXSTRING_INPUT( fixed_face, wxString, ST(2) )
;
    if( n != 7 )
    {
       delete[] array;
       croak( "Specified %d sizes, 7 wanted", n );
    }
    THIS->SetFonts( normal_face, fixed_face, array );
    delete[] array;        
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__HtmlDCRenderer_Render); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_Render)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 7)
       croak_xs_usage(cv,  "THIS, x, y, pagebreaks, from = 0, dont_render = 0, to = INT_MAX");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxArrayInt	pagebreaks;
	int	from;
	int	dont_render;
	int	to;
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;
	int	RETVAL;
	dXSTARG;

    wxPli_av_2_arrayint( aTHX_ ST(3), & pagebreaks )
;

	if (items < 5)
	    from = 0;
	else {
	    from = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    dont_render = 0;
	else {
	    dont_render = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    to = INT_MAX;
	else {
	    to = (int)SvIV(ST(6))
;
	}

	RETVAL = THIS->Render(x, y, pagebreaks, from, dont_render, to);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__HtmlDCRenderer_Render); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_Render)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, x, y, from = 0, dont_render = 0, maxHeight = INT_MAX, pagebreaks, number_of_pages = 0");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	int	from;
	int	dont_render;
	int	maxHeight;
	SV*	pagebreaks = ST(6)
;
	int	number_of_pages;
    int* array;
    int n = wxPli_av_2_intarray( aTHX_ pagebreaks, &array );
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;
	int	RETVAL;
	dXSTARG;

	if (items < 4)
	    from = 0;
	else {
	    from = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    dont_render = 0;
	else {
	    dont_render = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    maxHeight = INT_MAX;
	else {
	    maxHeight = (int)SvIV(ST(5))
;
	}

	if (items < 8)
	    number_of_pages = 0;
	else {
	    number_of_pages = (int)SvIV(ST(7))
;
	}
    RETVAL = THIS->Render( x, y, from, dont_render, maxHeight,
                           ( n == 0 ? NULL : array ), number_of_pages);
    delete[] array;
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif                        

XS_EUPXS(XS_Wx__HtmlDCRenderer_GetTotalHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlDCRenderer_GetTotalHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlDCRenderer *    THIS = (wxHtmlDCRenderer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlDCRenderer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTotalHeight();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/HtmlEasyPrinting.xs' from 'XS/HtmlDCRenderer.xs' */

#include <wx/html/htmprint.h>
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__HtmlEasyPrinting_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, name= wxT(\"Printing\"), parent= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlEasyPrinting *	RETVAL;
	wxString	name;
	wxWindow*	parent;

	if (items < 2)
	    name = wxT("Printing");
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	}

	RETVAL = new wxHtmlEasyPrinting(name, parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlEasyPrinting" );
    wxPli_thread_sv_register( aTHX_ "Wx::HtmlEasyPrinting", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__HtmlEasyPrinting_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, name = wxT(\"Printing\"), parent_frame = 0");
    {
	wxString	name;
	wxFrame*	parent_frame;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlEasyPrinting *	RETVAL;

	if (items < 2)
	    name = wxT("Printing");
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    parent_frame = 0;
	else {
    parent_frame = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Frame" )
;
	}

	RETVAL = new wxHtmlEasyPrinting(name, parent_frame);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlEasyPrinting" );
    wxPli_thread_sv_register( aTHX_ "Wx::HtmlEasyPrinting", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlEasyPrinting_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::HtmlEasyPrinting", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_PreviewFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PreviewFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, htmlFile");
    {
	wxString	htmlFile;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	bool	RETVAL;

    WXSTRING_INPUT( htmlFile, wxString, ST(1) )
;

	RETVAL = THIS->PreviewFile(htmlFile);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_PreviewText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PreviewText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, htmlText, basepath = wxEmptyString");
    {
	wxString	htmlText;
	wxString	basepath;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	bool	RETVAL;

    WXSTRING_INPUT( htmlText, wxString, ST(1) )
;

	if (items < 3)
	    basepath = wxEmptyString;
	else {
    WXSTRING_INPUT( basepath, wxString, ST(2) )
;
	}

	RETVAL = THIS->PreviewText(htmlText, basepath);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrintFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrintFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, htmlFile");
    {
	wxString	htmlFile;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	bool	RETVAL;

    WXSTRING_INPUT( htmlFile, wxString, ST(1) )
;

	RETVAL = THIS->PrintFile(htmlFile);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrintText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrintText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, htmlText, basepath = wxEmptyString");
    {
	wxString	htmlText;
	wxString	basepath;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	bool	RETVAL;

    WXSTRING_INPUT( htmlText, wxString, ST(1) )
;

	if (items < 3)
	    basepath = wxEmptyString;
	else {
    WXSTRING_INPUT( basepath, wxString, ST(2) )
;
	}

	RETVAL = THIS->PrintText(htmlText, basepath);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 5, 2 )
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrinterSetup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PrinterSetup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

	THIS->PrinterSetup();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__HtmlEasyPrinting_PageSetup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_PageSetup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

	THIS->PageSetup();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetHeader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetHeader)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, header, pg = wxPAGE_ALL");
    {
	wxString	header;
	int	pg;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

    WXSTRING_INPUT( header, wxString, ST(1) )
;

	if (items < 3)
	    pg = wxPAGE_ALL;
	else {
	    pg = (int)SvIV(ST(2))
;
	}

	THIS->SetHeader(header, pg);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetFonts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetFonts)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, normal_face, fixed_face, sizes");
    {
	wxString	normal_face;
	wxString	fixed_face;
	SV*	sizes = ST(3)
;
    int* array;
    int n = wxPli_av_2_intarray( aTHX_ sizes, &array );
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

    WXSTRING_INPUT( normal_face, wxString, ST(1) )
;

    WXSTRING_INPUT( fixed_face, wxString, ST(2) )
;
    if( n != 7 )
    {
       delete[] array;
       croak( "Specified %d sizes, 7 wanted", n );
    }
    THIS->SetFonts( normal_face, fixed_face, array );
    delete[] array;    
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetFooter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetFooter)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, header, pg = wxPAGE_ALL");
    {
	wxString	header;
	int	pg;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

    WXSTRING_INPUT( header, wxString, ST(1) )
;

	if (items < 3)
	    pg = wxPAGE_ALL;
	else {
	    pg = (int)SvIV(ST(2))
;
	}

	THIS->SetFooter(header, pg);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetPrintData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	wxPrintData *	RETVAL;

	RETVAL = THIS->GetPrintData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetPageSetupData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetPageSetupData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	wxPageSetupDialogData *	RETVAL;

	RETVAL = THIS->GetPageSetupData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_GetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetParentWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlEasyPrinting_SetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxHtmlEasyPrinting *    THIS = (wxHtmlEasyPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlEasyPrinting" )
;

	THIS->SetParentWindow(window);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Html.xs' from 'XS/HtmlEasyPrinting.xs' */

#endif

/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlParser.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/dc.h>
#include <wx/html/winpars.h>

XS_EUPXS(XS_Wx__HtmlParser_SetFS); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_SetFS)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fs");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxFileSystem*    fs = (wxFileSystem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::FileSystem" )
;
    try {
      THIS->SetFS( fs );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_GetFS); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_GetFS)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxFileSystem *	RETVAL;
    try {
      RETVAL = THIS->GetFS();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::FileSystem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlParser_OpenURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_OpenURL)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, type, url");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxFSFile *	RETVAL;
	wxHtmlURLType	type = (wxHtmlURLType)SvIV(ST(1))
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(2) )
;
    try {
      RETVAL = THIS->OpenURL( type, url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::FSFile" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlParser_Parse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_Parse)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, source");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxObject *	RETVAL;
	wxString	source;

    WXSTRING_INPUT( source, wxString, ST(1) )
;
    try {
      RETVAL = THIS->Parse( source );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlParser_InitParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_InitParser)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, source");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxString	source;

    WXSTRING_INPUT( source, wxString, ST(1) )
;
    try {
      THIS->InitParser( source );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_DoneParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_DoneParser)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
    try {
      THIS->DoneParser();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_StopParsing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_StopParsing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
    try {
      THIS->StopParsing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_GetCurrentTag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_GetCurrentTag)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetCurrentTag();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlParser_GetProduct); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_GetProduct)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxObject *	RETVAL;
    try {
      RETVAL = THIS->GetProduct();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlParser_AddTagHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_AddTagHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxHtmlTagHandler*    handler = (wxHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlTagHandler" )
;
    try {
      THIS->AddTagHandler( handler );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_PushTagHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_PushTagHandler)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, handler, tags");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxHtmlTagHandler*    handler = (wxHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlTagHandler" )
;
	wxString	tags;

    WXSTRING_INPUT( tags, wxString, ST(2) )
;
    try {
      THIS->PushTagHandler( handler, tags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_PopTagHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_PopTagHandler)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
    try {
      THIS->PopTagHandler();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_SetSource); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_SetSource)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, src");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxString	src;

    WXSTRING_INPUT( src, wxString, ST(1) )
;
    try {
      THIS->SetSource( src );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_SetSourceAndSaveState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_SetSourceAndSaveState)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, src");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	wxString	src;

    WXSTRING_INPUT( src, wxString, ST(1) )
;
    try {
      THIS->SetSourceAndSaveState( src );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlParser_RestoreState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlParser_RestoreState)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlParser *    THIS = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlParser" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->RestoreState();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_OpenURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_OpenURL)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, type, url");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxFSFile *	RETVAL;
	wxHtmlURLType	type = (wxHtmlURLType)SvIV(ST(1))
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(2) )
;
    try {
      RETVAL = THIS->OpenURL( type, url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::FSFile" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetDC)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, dc, pixel_scale= 1.0");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	double	pixel_scale;

	if (items < 3)
	    pixel_scale = 1.0;
	else {
	    pixel_scale = (double)SvNV(ST(2))
;
	}
    try {
      THIS->SetDC( dc, pixel_scale );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetDC)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxDC *	RETVAL;
    try {
      RETVAL = THIS->GetDC();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::DC", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetPixelScale); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetPixelScale)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPixelScale();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetCharHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetCharHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCharHeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetCharWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetCharWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCharWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSpp_44269c4c_024638
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__HtmlWinParser_GetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlWindow *	RETVAL;
    try {
      RETVAL = THIS->GetWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_44269c4c_098129
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__HtmlWinParser_GetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxWindow *	RETVAL;
     RETVAL = THIS->GetWindowInterface()->GetHTMLWindow(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlWinParser_GetContainer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetContainer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlContainerCell *	RETVAL;
    try {
      RETVAL = THIS->GetContainer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_OpenContainer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_OpenContainer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlContainerCell *	RETVAL;
    try {
      RETVAL = THIS->OpenContainer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetContainer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetContainer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, c");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlContainerCell *	RETVAL;
	wxHtmlContainerCell*    c = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlContainerCell" )
;
    try {
      RETVAL = THIS->SetContainer( c );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_CloseContainer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_CloseContainer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlContainerCell *	RETVAL;
    try {
      RETVAL = THIS->CloseContainer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	s = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontSize( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontBold)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, x");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	x = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontBold( x );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontItalic)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, x");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	x = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontItalic( x );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, x");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	x = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontUnderlined( x );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontFixed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontFixed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontFixed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontFixed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontFixed)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, x");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	x = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontFixed( x );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetFontFace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetFontFace)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFontFace();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetFontFace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetFontFace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, face");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxString	face;

    WXSTRING_INPUT( face, wxString, ST(1) )
;
    try {
      THIS->SetFontFace( face );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetAlign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetAlign)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlign();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetAlign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetAlign)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, a");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	int	a = (int)SvIV(ST(1))
;
    try {
      THIS->SetAlign( a );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetLinkColor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetLinkColor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetLinkColor() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetLinkColor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetLinkColor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, clr");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxColour*    clr = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetLinkColor( *( clr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetActualColor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetActualColor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetActualColor() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetActualColor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetActualColor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, clr");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxColour*    clr = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetActualColor( *( clr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetLink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetLink)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlLinkInfo *	RETVAL;
    try {
      RETVAL = new wxHtmlLinkInfo( THIS->GetLink() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlLinkInfo" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_SetLink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetLink)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, link");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxHtmlLinkInfo*    link = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlLinkInfo" )
;
    try {
      THIS->SetLink( *( link ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if !wxUSE_UNICODE
#define XSpp_44269c4c_009932
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__HtmlWinParser_SetInputEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_SetInputEncoding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enc");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxFontEncoding	enc = (wxFontEncoding)SvIV(ST(1))
;
    try {
      THIS->SetInputEncoding( enc );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetInputEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetInputEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxFontEncoding	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInputEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetOutputEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetOutputEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxFontEncoding	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOutputEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlWinParser_GetEncodingConverter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_GetEncodingConverter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxEncodingConverter *	RETVAL;
    try {
      RETVAL = THIS->GetEncodingConverter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlWinParser_CreateCurrentFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWinParser_CreateCurrentFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlWinParser *    THIS = (wxHtmlWinParser *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWinParser" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = THIS->CreateCurrentFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlParser.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlTagHandler.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/html/htmlpars.h>
#include "xspp/htmltag.h"

XS_EUPXS(XS_Wx__HtmlTagHandler_SetParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTagHandler_SetParser)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parser");
    {
	wxHtmlTagHandler *    THIS = (wxHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTagHandler" )
;
	wxHtmlParser*    parser = (wxHtmlParser *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlParser" )
;
    try {
      THIS->SetParser( parser );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlTagHandler_GetSupportedTags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTagHandler_GetSupportedTags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTagHandler *    THIS = (wxHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTagHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetSupportedTags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTagHandler_HandleTag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTagHandler_HandleTag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tag");
    {
	wxHtmlTagHandler *    THIS = (wxHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTagHandler" )
;
	bool	RETVAL;
	wxHtmlTag*    tag = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlTag" )
;
    try {
      RETVAL = THIS->HandleTag( *( tag ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHtmlTagHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlTagHandler_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHtmlTagHandler *	RETVAL;
     RETVAL = new wxPlHtmlTagHandler( CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlHtmlTagHandler_GetParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlTagHandler_GetParser)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlHtmlTagHandler *    THIS = (wxPlHtmlTagHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlHtmlTagHandler" )
;
	wxHtmlParser *	RETVAL;
    try {
      RETVAL = THIS->GetParser();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHtmlWinTagHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlWinTagHandler_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHtmlWinTagHandler *	RETVAL;
     RETVAL = new wxPlHtmlWinTagHandler( CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlHtmlWinTagHandler_GetParser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlWinTagHandler_GetParser)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlHtmlWinTagHandler *    THIS = (wxPlHtmlWinTagHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlHtmlWinTagHandler" )
;
	wxHtmlWinParser *	RETVAL;
    try {
      RETVAL = THIS->GetParser();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlTagHandler.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlTag.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/html/htmltag.h>

XS_EUPXS(XS_Wx__HtmlTag_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetParent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetFirstSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetFirstSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetFirstSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetLastSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetLastSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetLastSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetChildren();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetPreviousSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetPreviousSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetPreviousSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetNextSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetNextSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetNextSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetNextTag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetNextTag)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxHtmlTag *	RETVAL;
    try {
      RETVAL = THIS->GetNextTag();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlTag" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_HasParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_HasParam)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, par");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	bool	RETVAL;
	wxString	par;

    WXSTRING_INPUT( par, wxString, ST(1) )
;
    try {
      RETVAL = THIS->HasParam( par );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetParam)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, par, with_commas= false");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxString	RETVAL;
	wxString	par;
	bool	with_commas;

    WXSTRING_INPUT( par, wxString, ST(1) )
;

	if (items < 3)
	    with_commas = false;
	else {
	    with_commas = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetParam( par, with_commas );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetAllParams); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetAllParams)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetAllParams();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_HasEnding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_HasEnding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasEnding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_75b0c414_050900
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__HtmlTag_GetBeginPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetBeginPos)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBeginPos();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetEndPos1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetEndPos1)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetEndPos1();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlTag_GetEndPos2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetEndPos2)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetEndPos2();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlTag_GetParamAsColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetParamAsColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, par");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxString	par;

    WXSTRING_INPUT( par, wxString, ST(1) )
;
    wxColour col;
    bool ret = THIS->GetParamAsColour( par, &col );

    EXTEND( SP, 2 );
    XPUSHs( newSViv( ret ) );
    XPUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                   ( ret ? new wxColour( col ) : NULL ),
                                   "Wx::Colour" ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HtmlTag_GetParamAsInt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlTag_GetParamAsInt)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, par");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHtmlTag *    THIS = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlTag" )
;
	wxString	par;

    WXSTRING_INPUT( par, wxString, ST(1) )
;
    int val;
    bool ret = THIS->GetParamAsInt( par, &val );

    EXTEND( SP, 2 );
    XPUSHs( newSViv( ret ) );
    XPUSHs( newSViv( val ) );
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlTag.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlCell.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/html/htmlcell.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlCell_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = new wxHtmlCell();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HtmlCell_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
      delete THIS; 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_SetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlContainerCell*    p = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlContainerCell" )
;
    try {
      THIS->SetParent( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlContainerCell *	RETVAL;
    try {
      RETVAL = THIS->GetParent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetPosX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetPosX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPosX();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetPosY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetPosY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPosY();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetHeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetDescent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetDescent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetDescent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_049549
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__HtmlCell_IsFormattingCell); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_IsFormattingCell)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsFormattingCell();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlCell_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_SetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxString	id;

    WXSTRING_INPUT( id, wxString, ST(1) )
;
    try {
      THIS->SetId( id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_GetLink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetLink)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, x= 0, y= 0");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlLinkInfo *	RETVAL;
	int	x;
	int	y;

	if (items < 2)
	    x = 0;
	else {
	    x = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    y = 0;
	else {
	    y = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetLink( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlLinkInfo" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 ) && WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSpp_7de18e25_076593
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__HtmlCell_GetCursor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetCursor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxCursor *	RETVAL;
    try {
      RETVAL = new wxCursor( THIS->GetCursor() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Cursor", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlCell_GetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = THIS->GetNext();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_037557
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__HtmlCell_GetFirstChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetFirstChild)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = THIS->GetFirstChild();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlCell_SetPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetPos)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      THIS->SetPos( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_SetLink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetLink)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, link");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlLinkInfo*    link = (wxHtmlLinkInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlLinkInfo" )
;
    try {
      THIS->SetLink( *( link ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_SetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetNext)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cell");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell*    cell = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlCell" )
;
    try {
      THIS->SetNext( cell );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_Layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_Layout)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, w");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	int	w = (int)SvIV(ST(1))
;
    try {
      THIS->Layout( w );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlCell_SetCanLiveOnPagebreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_SetCanLiveOnPagebreak)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, can");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	bool	can = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetCanLiveOnPagebreak( can );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_010769
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__HtmlCell_IsLinebreakAllowed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_IsLinebreakAllowed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsLinebreakAllowed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__HtmlCell_IsTerminalCell); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_IsTerminalCell)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsTerminalCell();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_047669
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__HtmlCell_FindCellByPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_FindCellByPos)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, x, y, flags= wxHTML_FIND_EXACT");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
	unsigned int	flags;

	if (items < 4)
	    flags = wxHTML_FIND_EXACT;
	else {
    flags = (unsigned int)SvUV( ST(3) )
;
	}
    try {
      RETVAL = THIS->FindCellByPos( x, y, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetAbsPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetAbsPos)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetAbsPos();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetFirstTerminal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetFirstTerminal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = THIS->GetFirstTerminal();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetLastTerminal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetLastTerminal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
    try {
      RETVAL = THIS->GetLastTerminal();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_GetDepth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_GetDepth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetDepth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_IsBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_IsBefore)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cell");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	bool	RETVAL;
	wxHtmlCell*    cell = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlCell" )
;
    try {
      RETVAL = THIS->IsBefore( cell );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlCell_ConvertToText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_ConvertToText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sel");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxString	RETVAL;
	wxHtmlSelection*    sel = (wxHtmlSelection *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlSelection" )
;
    try {
      RETVAL = THIS->ConvertToText( sel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_7de18e25_025405
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__HtmlCell_FindCellByPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlCell_FindCellByPos)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxHtmlCell *    THIS = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlCell" )
;
	wxHtmlCell *	RETVAL;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
    try {
      RETVAL = THIS->FindCellByPos( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_002555
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__HtmlWordCell_SetPreviousWord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWordCell_SetPreviousWord)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cell");
    {
	wxHtmlWordCell *    THIS = (wxHtmlWordCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlWordCell" )
;
	wxHtmlWordCell*    cell = (wxHtmlWordCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlWordCell" )
;
    try {
      THIS->SetPreviousWord( cell );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlContainerCell_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, parent");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlContainerCell *	RETVAL;
	wxHtmlContainerCell*    parent = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlContainerCell" )
;
    try {
      RETVAL = new wxHtmlContainerCell( parent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HtmlContainerCell_InsertCell); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_InsertCell)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cell");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxHtmlCell*    cell = (wxHtmlCell *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlCell" )
;
    try {
      THIS->InsertCell( cell );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlignHor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlignHor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, al");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	al = (int)SvIV(ST(1))
;
    try {
      THIS->SetAlignHor( al );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_GetAlignHor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_GetAlignHor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignHor();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlignVer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlignVer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, al");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	al = (int)SvIV(ST(1))
;
    try {
      THIS->SetAlignVer( al );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_GetAlignVer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_GetAlignVer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignVer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetIndent)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, i, what, units= wxHTML_UNITS_PIXELS");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	i = (int)SvIV(ST(1))
;
	int	what = (int)SvIV(ST(2))
;
	int	units;

	if (items < 4)
	    units = wxHTML_UNITS_PIXELS;
	else {
	    units = (int)SvIV(ST(3))
;
	}
    try {
      THIS->SetIndent( i, what, units );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_GetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_GetIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ind");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	RETVAL;
	dXSTARG;
	int	ind = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetIndent( ind );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlContainerCell_GetIndentUnits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_GetIndentUnits)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ind");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	RETVAL;
	dXSTARG;
	int	ind = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetIndentUnits( ind );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetAlign)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tag");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxHtmlTag*    tag = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlTag" )
;
    try {
      THIS->SetAlign( *( tag ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetWidthFloat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetWidthFloat)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, w, units");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	w = (int)SvIV(ST(1))
;
	int	units = (int)SvIV(ST(2))
;
    try {
      THIS->SetWidthFloat( w, units );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetWidthFloatTag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetWidthFloatTag)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, tag, pixel_scale= 1.0");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxHtmlTag*    tag = (wxHtmlTag *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HtmlTag" )
;
	double	pixel_scale;

	if (items < 3)
	    pixel_scale = 1.0;
	else {
	    pixel_scale = (double)SvNV(ST(2))
;
	}
    try {
      THIS->SetWidthFloat( *( tag ), pixel_scale );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetMinHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetMinHeight)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, h, align= wxHTML_ALIGN_TOP");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	int	h = (int)SvIV(ST(1))
;
	int	align;

	if (items < 3)
	    align = wxHTML_ALIGN_TOP;
	else {
	    align = (int)SvIV(ST(2))
;
	}
    try {
      THIS->SetMinHeight( h, align );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, clr");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxColour*    clr = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetBackgroundColour( *( clr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlContainerCell_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetBackgroundColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlContainerCell_SetBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_SetBorder)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, clr1, clr2");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	wxColour*    clr1 = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColour*    clr2 = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetBorder( *( clr1 ), *( clr2 ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_7de18e25_022187
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__HtmlContainerCell_RemoveExtraSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlContainerCell_RemoveExtraSpacing)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, top, bottom");
    {
	wxHtmlContainerCell *    THIS = (wxHtmlContainerCell *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlContainerCell" )
;
	bool	top = (bool)SvTRUE(ST(1))
;
	bool	bottom = (bool)SvTRUE(ST(2))
;
    try {
      THIS->RemoveExtraSpacing( top, bottom );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlColourCell_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlColourCell_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, clr, flags= wxHTML_CLR_FOREGROUND");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlColourCell *	RETVAL;
	wxColour*    clr = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	int	flags;

	if (items < 3)
	    flags = wxHTML_CLR_FOREGROUND;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxHtmlColourCell( *( clr ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlFontCell_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlFontCell_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, font");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlFontCell *	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = new wxHtmlFontCell( font );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlWidgetCell_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlWidgetCell_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, window, w= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlWidgetCell *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	w;

	if (items < 3)
	    w = 0;
	else {
	    w = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxHtmlWidgetCell( window, w );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlCell.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlListBox.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 0 )
#define XSpp_ed77be2f_010211
#include <wx/clntdata.h>
#include "cpp/helpers.h"
#include <wx/htmllbox.h>
#include "cpp/overload.h"
#include "xspp/htmllbox.h"
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__HtmlListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxVListBoxNameStr");
    {
	wxHtmlListBox *    THIS = (wxHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlListBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxVListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlListBox_GetFileSystem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlListBox_GetFileSystem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlListBox *    THIS = (wxHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlListBox" )
;
	wxFileSystem *	RETVAL;
    RETVAL = &THIS->GetFileSystem();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::FileSystem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHtmlListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHtmlListBox *	RETVAL;
     RETVAL = new wxPlHtmlListBox( CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHtmlListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHtmlListBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlHtmlListBox( CLASS, parent, id, pos, size,
                                              style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlHtmlListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHtmlListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlHtmlListBox::new" )
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_ed77be2f_098198
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__SimpleHtmlListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSimpleHtmlListBox *	RETVAL;
     RETVAL = new wxSimpleHtmlListBox;
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SimpleHtmlListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, choices, style= 0, validator= wxDefaultValidatorPtr, name= wxSimpleHtmlListBoxNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSimpleHtmlListBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	wxArrayString	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

    wxPli_av_2_arraystring( aTHX_ ST(5), & choices )
;

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxSimpleHtmlListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxSimpleHtmlListBox( parent, id, pos, size,
                                                  choices, style, *validator,
                                                  name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SimpleHtmlListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, choices, style= 0, validator= wxDefaultValidatorPtr, name= wxSimpleHtmlListBoxNameStr");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	wxArrayString	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

    wxPli_av_2_arraystring( aTHX_ ST(5), & choices )
;

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxSimpleHtmlListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, choices, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_GetString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	wxString	RETVAL;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetString( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_SetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_SetString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, s");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(2) )
;
    try {
      THIS->SetString( n, s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
    THIS->wxVListBox::Clear();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->Delete( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendStrings)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, strings");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	wxArrayString	strings;

    wxPli_av_2_arraystring( aTHX_ ST(1), & strings )
;
    try {
      THIS->Append( strings );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	wxString	item;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Append( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_AppendData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxSimpleHtmlListBox *    THIS = (wxSimpleHtmlListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SimpleHtmlListBox" )
;
	wxString	item;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->Append( item, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SimpleHtmlListBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__SimpleHtmlListBox_Append); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHtmlListBox_Append)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr, AppendStrings )
        MATCH_REDISP( wxPliOvl_s_s, AppendData )
        MATCH_REDISP( wxPliOvl_s, AppendString )
    END_OVERLOAD( Wx::SimpleHtmlListBox::Append )
	PUTBACK;
	return;
    }
}

#endif
#endif

/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlListBox.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlPrintout.xsp' from 'Html.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/html/htmprint.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HtmlPrintout_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, title= wxT(\"Printout\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHtmlPrintout *	RETVAL;
	wxString	title;

	if (items < 2)
	    title = wxT("Printout");
	else {
    WXSTRING_INPUT( title, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxHtmlPrintout( title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HtmlPrintout" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HtmlPrintout_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
     delete THIS; 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetHtmlText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetHtmlText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, html, basepath= wxEmptyString, isdir= true");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	wxString	html;
	wxString	basepath;
	bool	isdir;

    WXSTRING_INPUT( html, wxString, ST(1) )
;

	if (items < 3)
	    basepath = wxEmptyString;
	else {
    WXSTRING_INPUT( basepath, wxString, ST(2) )
;
	}

	if (items < 4)
	    isdir = true;
	else {
	    isdir = (bool)SvTRUE(ST(3))
;
	}
    try {
      THIS->SetHtmlText( html, basepath, isdir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetHtmlFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetHtmlFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, htmlfile");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	wxString	htmlfile;

    WXSTRING_INPUT( htmlfile, wxString, ST(1) )
;
    try {
      THIS->SetHtmlFile( htmlfile );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetHeader); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetHeader)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, header, pg= wxPAGE_ALL");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	wxString	header;
	int	pg;

    WXSTRING_INPUT( header, wxString, ST(1) )
;

	if (items < 3)
	    pg = wxPAGE_ALL;
	else {
	    pg = (int)SvIV(ST(2))
;
	}
    try {
      THIS->SetHeader( header, pg );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetFooter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetFooter)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, footer, pg= wxPAGE_ALL");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	wxString	footer;
	int	pg;

    WXSTRING_INPUT( footer, wxString, ST(1) )
;

	if (items < 3)
	    pg = wxPAGE_ALL;
	else {
	    pg = (int)SvIV(ST(2))
;
	}
    try {
      THIS->SetFooter( footer, pg );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetStandardFonts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetStandardFonts)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "THIS, size= -1, normal_face= wxEmptyString, fixed_face= wxEmptyString");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	int	size;
	wxString	normal_face;
	wxString	fixed_face;

	if (items < 2)
	    size = -1;
	else {
	    size = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    normal_face = wxEmptyString;
	else {
    WXSTRING_INPUT( normal_face, wxString, ST(2) )
;
	}

	if (items < 4)
	    fixed_face = wxEmptyString;
	else {
    WXSTRING_INPUT( fixed_face, wxString, ST(3) )
;
	}
    try {
      THIS->SetStandardFonts( size, normal_face, fixed_face );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetMargins)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 6)
       croak_xs_usage(cv,  "THIS, top= 25.2, bottom= 25.2, left= 25.2, right= 25.2, spaces= 5");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	float	top;
	float	bottom;
	float	left;
	float	right;
	float	spaces;

	if (items < 2)
	    top = 25.2;
	else {
	    top = (float)SvNV(ST(1))
;
	}

	if (items < 3)
	    bottom = 25.2;
	else {
	    bottom = (float)SvNV(ST(2))
;
	}

	if (items < 4)
	    left = 25.2;
	else {
	    left = (float)SvNV(ST(3))
;
	}

	if (items < 5)
	    right = 25.2;
	else {
	    right = (float)SvNV(ST(4))
;
	}

	if (items < 6)
	    spaces = 5;
	else {
	    spaces = (float)SvNV(ST(5))
;
	}
    try {
      THIS->SetMargins( top, bottom, left, right, spaces );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_OnPrintPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_OnPrintPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	bool	RETVAL;
	int	page = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->OnPrintPage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlPrintout_HasPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_HasPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	bool	RETVAL;
	int	page = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasPage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlPrintout_OnBeginDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_OnBeginDocument)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, startPage, endPage");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
	bool	RETVAL;
	int	startPage = (int)SvIV(ST(1))
;
	int	endPage = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->OnBeginDocument( startPage, endPage );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HtmlPrintout_OnPreparePrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_OnPreparePrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
    try {
      THIS->OnPreparePrinting();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_CleanUpStatics); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_CleanUpStatics)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
    try {
      wxHtmlPrintout::CleanUpStatics();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HtmlPrintout_GetPageInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_GetPageInfo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int minPage, maxPage, pageFrom, pageTo;
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;
    THIS->wxHtmlPrintout::GetPageInfo( &minPage, &maxPage, &pageFrom, &pageTo );
    EXTEND( SP, 4 );
    PUSHs( sv_2mortal( newSViv( minPage ) ) );
    PUSHs( sv_2mortal( newSViv( maxPage ) ) );
    PUSHs( sv_2mortal( newSViv( pageFrom ) ) );
    PUSHs( sv_2mortal( newSViv( pageTo ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HtmlPrintout_SetFonts); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HtmlPrintout_SetFonts)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, normal_face, fixed_face, sizes");
    {
	wxString	normal_face;
	wxString	fixed_face;
	SV*	sizes = ST(3)
;
    int* array;
    int n = wxPli_av_2_intarray( aTHX_ sizes, &array );
	wxHtmlPrintout *    THIS = (wxHtmlPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HtmlPrintout" )
;

    WXSTRING_INPUT( normal_face, wxString, ST(1) )
;

    WXSTRING_INPUT( fixed_face, wxString, ST(2) )
;
    if( n != 7 )
    {
       delete[] array;
       croak( "Specified %d sizes, 7 wanted", n );
    }
    THIS->wxHtmlPrintout::SetFonts( normal_face, fixed_face, array );
    delete[] array;
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'Html.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/HtmlPrintout.xsp' */

#include "cpp/ht_constants.cpp"
#include "cpp/ovl_const.cpp"
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__Html); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__Html)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

#if XSubPPtmpAAAA
        newXS_deffile("Wx::HtmlCellEvent::GetCell", XS_Wx__HtmlCellEvent_GetCell);
        newXS_deffile("Wx::HtmlCellEvent::GetPoint", XS_Wx__HtmlCellEvent_GetPoint);
        newXS_deffile("Wx::HtmlCellEvent::GetMouseEvent", XS_Wx__HtmlCellEvent_GetMouseEvent);
        newXS_deffile("Wx::HtmlCellEvent::SetLinkClicked", XS_Wx__HtmlCellEvent_SetLinkClicked);
        newXS_deffile("Wx::HtmlCellEvent::GetLinkClicked", XS_Wx__HtmlCellEvent_GetLinkClicked);
        newXS_deffile("Wx::HtmlLinkEvent::GetLinkInfo", XS_Wx__HtmlLinkEvent_GetLinkInfo);
#endif
        newXS_deffile("Wx::HtmlLinkInfo::GetEvent", XS_Wx__HtmlLinkInfo_GetEvent);
        newXS_deffile("Wx::HtmlLinkInfo::GetHtmlCell", XS_Wx__HtmlLinkInfo_GetHtmlCell);
        newXS_deffile("Wx::HtmlLinkInfo::GetHref", XS_Wx__HtmlLinkInfo_GetHref);
        newXS_deffile("Wx::HtmlLinkInfo::GetTarget", XS_Wx__HtmlLinkInfo_GetTarget);
        newXS_deffile("Wx::HtmlWindow::new", XS_Wx__HtmlWindow_new);
        newXS_deffile("Wx::HtmlWindow::AppendToPage", XS_Wx__HtmlWindow_AppendToPage);
        newXS_deffile("Wx::HtmlWindow::GetOpenedAnchor", XS_Wx__HtmlWindow_GetOpenedAnchor);
        newXS_deffile("Wx::HtmlWindow::GetOpenedPage", XS_Wx__HtmlWindow_GetOpenedPage);
        newXS_deffile("Wx::HtmlWindow::GetOpenedPageTitle", XS_Wx__HtmlWindow_GetOpenedPageTitle);
        newXS_deffile("Wx::HtmlWindow::GetParser", XS_Wx__HtmlWindow_GetParser);
        newXS_deffile("Wx::HtmlWindow::GetRelatedFrame", XS_Wx__HtmlWindow_GetRelatedFrame);
        newXS_deffile("Wx::HtmlWindow::HistoryBack", XS_Wx__HtmlWindow_HistoryBack);
        newXS_deffile("Wx::HtmlWindow::HistoryCanForward", XS_Wx__HtmlWindow_HistoryCanForward);
        newXS_deffile("Wx::HtmlWindow::HistoryCanBack", XS_Wx__HtmlWindow_HistoryCanBack);
        newXS_deffile("Wx::HtmlWindow::HistoryClear", XS_Wx__HtmlWindow_HistoryClear);
        newXS_deffile("Wx::HtmlWindow::HistoryForward", XS_Wx__HtmlWindow_HistoryForward);
        newXS_deffile("Wx::HtmlWindow::LoadFile", XS_Wx__HtmlWindow_LoadFile);
        newXS_deffile("Wx::HtmlWindow::LoadPage", XS_Wx__HtmlWindow_LoadPage);
        newXS_deffile("Wx::HtmlWindow::OnLinkClicked", XS_Wx__HtmlWindow_OnLinkClicked);
        newXS_deffile("Wx::HtmlWindow::OnSetTitle", XS_Wx__HtmlWindow_OnSetTitle);
        newXS_deffile("Wx::HtmlWindow::ReadCustomization", XS_Wx__HtmlWindow_ReadCustomization);
        newXS_deffile("Wx::HtmlWindow::SetBorders", XS_Wx__HtmlWindow_SetBorders);
        newXS_deffile("Wx::HtmlWindow::SetFonts", XS_Wx__HtmlWindow_SetFonts);
        newXS_deffile("Wx::HtmlWindow::SetPage", XS_Wx__HtmlWindow_SetPage);
        newXS_deffile("Wx::HtmlWindow::SetRelatedFrame", XS_Wx__HtmlWindow_SetRelatedFrame);
        newXS_deffile("Wx::HtmlWindow::SetRelatedStatusBar", XS_Wx__HtmlWindow_SetRelatedStatusBar);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::HtmlWindow::SelectWord", XS_Wx__HtmlWindow_SelectWord);
        newXS_deffile("Wx::HtmlWindow::SelectLine", XS_Wx__HtmlWindow_SelectLine);
        newXS_deffile("Wx::HtmlWindow::SelectAll", XS_Wx__HtmlWindow_SelectAll);
        newXS_deffile("Wx::HtmlWindow::SelectionToText", XS_Wx__HtmlWindow_SelectionToText);
        newXS_deffile("Wx::HtmlWindow::ToText", XS_Wx__HtmlWindow_ToText);
#endif
        newXS_deffile("Wx::HtmlWindow::WriteCustomization", XS_Wx__HtmlWindow_WriteCustomization);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::BestHelpController::new", XS_Wx__BestHelpController_new);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::BestHelpController::new", XS_Wx__BestHelpController_new);
#endif
        newXS_deffile("Wx::HtmlHelpController::new", XS_Wx__HtmlHelpController_new);
        newXS_deffile("Wx::HtmlHelpController::AddBook", XS_Wx__HtmlHelpController_AddBook);
        newXS_deffile("Wx::HtmlHelpController::Display", XS_Wx__HtmlHelpController_Display);
        newXS_deffile("Wx::HtmlHelpController::DisplayId", XS_Wx__HtmlHelpController_DisplayId);
        newXS_deffile("Wx::HtmlHelpController::DisplayContents", XS_Wx__HtmlHelpController_DisplayContents);
        newXS_deffile("Wx::HtmlHelpController::DisplayIndex", XS_Wx__HtmlHelpController_DisplayIndex);
        newXS_deffile("Wx::HtmlHelpController::KeywordSearch", XS_Wx__HtmlHelpController_KeywordSearch);
        newXS_deffile("Wx::HtmlHelpController::ReadCustomization", XS_Wx__HtmlHelpController_ReadCustomization);
        newXS_deffile("Wx::HtmlHelpController::SetTempDir", XS_Wx__HtmlHelpController_SetTempDir);
        newXS_deffile("Wx::HtmlHelpController::SetTitleFormat", XS_Wx__HtmlHelpController_SetTitleFormat);
        newXS_deffile("Wx::HtmlHelpController::UseConfig", XS_Wx__HtmlHelpController_UseConfig);
        newXS_deffile("Wx::HtmlHelpController::WriteCustomization", XS_Wx__HtmlHelpController_WriteCustomization);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::HtmlDCRenderer::new", XS_Wx__HtmlDCRenderer_new);
        newXS_deffile("Wx::HtmlDCRenderer::CLONE", XS_Wx__HtmlDCRenderer_CLONE);
        newXS_deffile("Wx::HtmlDCRenderer::DESTROY", XS_Wx__HtmlDCRenderer_DESTROY);
        newXS_deffile("Wx::HtmlDCRenderer::SetDC", XS_Wx__HtmlDCRenderer_SetDC);
        newXS_deffile("Wx::HtmlDCRenderer::SetSize", XS_Wx__HtmlDCRenderer_SetSize);
        newXS_deffile("Wx::HtmlDCRenderer::SetHtmlText", XS_Wx__HtmlDCRenderer_SetHtmlText);
        newXS_deffile("Wx::HtmlDCRenderer::SetFonts", XS_Wx__HtmlDCRenderer_SetFonts);
#if XSubPPtmpAAAF
        newXS_deffile("Wx::HtmlDCRenderer::Render", XS_Wx__HtmlDCRenderer_Render);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::HtmlDCRenderer::Render", XS_Wx__HtmlDCRenderer_Render);
#endif
        newXS_deffile("Wx::HtmlDCRenderer::GetTotalHeight", XS_Wx__HtmlDCRenderer_GetTotalHeight);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::HtmlEasyPrinting::new", XS_Wx__HtmlEasyPrinting_new);
#endif
#if XSubPPtmpAAAI
        newXS_deffile("Wx::HtmlEasyPrinting::new", XS_Wx__HtmlEasyPrinting_new);
#endif
        newXS_deffile("Wx::HtmlEasyPrinting::CLONE", XS_Wx__HtmlEasyPrinting_CLONE);
        newXS_deffile("Wx::HtmlEasyPrinting::DESTROY", XS_Wx__HtmlEasyPrinting_DESTROY);
        newXS_deffile("Wx::HtmlEasyPrinting::PreviewFile", XS_Wx__HtmlEasyPrinting_PreviewFile);
        newXS_deffile("Wx::HtmlEasyPrinting::PreviewText", XS_Wx__HtmlEasyPrinting_PreviewText);
        newXS_deffile("Wx::HtmlEasyPrinting::PrintFile", XS_Wx__HtmlEasyPrinting_PrintFile);
        newXS_deffile("Wx::HtmlEasyPrinting::PrintText", XS_Wx__HtmlEasyPrinting_PrintText);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::HtmlEasyPrinting::PrinterSetup", XS_Wx__HtmlEasyPrinting_PrinterSetup);
#endif
        newXS_deffile("Wx::HtmlEasyPrinting::PageSetup", XS_Wx__HtmlEasyPrinting_PageSetup);
        newXS_deffile("Wx::HtmlEasyPrinting::SetHeader", XS_Wx__HtmlEasyPrinting_SetHeader);
        newXS_deffile("Wx::HtmlEasyPrinting::SetFonts", XS_Wx__HtmlEasyPrinting_SetFonts);
        newXS_deffile("Wx::HtmlEasyPrinting::SetFooter", XS_Wx__HtmlEasyPrinting_SetFooter);
        newXS_deffile("Wx::HtmlEasyPrinting::GetPrintData", XS_Wx__HtmlEasyPrinting_GetPrintData);
        newXS_deffile("Wx::HtmlEasyPrinting::GetPageSetupData", XS_Wx__HtmlEasyPrinting_GetPageSetupData);
#if XSubPPtmpAAAK
        newXS_deffile("Wx::HtmlEasyPrinting::GetParentWindow", XS_Wx__HtmlEasyPrinting_GetParentWindow);
        newXS_deffile("Wx::HtmlEasyPrinting::SetParentWindow", XS_Wx__HtmlEasyPrinting_SetParentWindow);
#endif
#endif
        newXS_deffile("Wx::HtmlParser::SetFS", XS_Wx__HtmlParser_SetFS);
        newXS_deffile("Wx::HtmlParser::GetFS", XS_Wx__HtmlParser_GetFS);
        newXS_deffile("Wx::HtmlParser::OpenURL", XS_Wx__HtmlParser_OpenURL);
        newXS_deffile("Wx::HtmlParser::Parse", XS_Wx__HtmlParser_Parse);
        newXS_deffile("Wx::HtmlParser::InitParser", XS_Wx__HtmlParser_InitParser);
        newXS_deffile("Wx::HtmlParser::DoneParser", XS_Wx__HtmlParser_DoneParser);
        newXS_deffile("Wx::HtmlParser::StopParsing", XS_Wx__HtmlParser_StopParsing);
        newXS_deffile("Wx::HtmlParser::GetCurrentTag", XS_Wx__HtmlParser_GetCurrentTag);
        newXS_deffile("Wx::HtmlParser::GetProduct", XS_Wx__HtmlParser_GetProduct);
        newXS_deffile("Wx::HtmlParser::AddTagHandler", XS_Wx__HtmlParser_AddTagHandler);
        newXS_deffile("Wx::HtmlParser::PushTagHandler", XS_Wx__HtmlParser_PushTagHandler);
        newXS_deffile("Wx::HtmlParser::PopTagHandler", XS_Wx__HtmlParser_PopTagHandler);
        newXS_deffile("Wx::HtmlParser::SetSource", XS_Wx__HtmlParser_SetSource);
        newXS_deffile("Wx::HtmlParser::SetSourceAndSaveState", XS_Wx__HtmlParser_SetSourceAndSaveState);
        newXS_deffile("Wx::HtmlParser::RestoreState", XS_Wx__HtmlParser_RestoreState);
        newXS_deffile("Wx::HtmlWinParser::OpenURL", XS_Wx__HtmlWinParser_OpenURL);
        newXS_deffile("Wx::HtmlWinParser::SetDC", XS_Wx__HtmlWinParser_SetDC);
        newXS_deffile("Wx::HtmlWinParser::GetDC", XS_Wx__HtmlWinParser_GetDC);
        newXS_deffile("Wx::HtmlWinParser::GetPixelScale", XS_Wx__HtmlWinParser_GetPixelScale);
        newXS_deffile("Wx::HtmlWinParser::GetCharHeight", XS_Wx__HtmlWinParser_GetCharHeight);
        newXS_deffile("Wx::HtmlWinParser::GetCharWidth", XS_Wx__HtmlWinParser_GetCharWidth);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::HtmlWinParser::GetWindow", XS_Wx__HtmlWinParser_GetWindow);
#endif
#if XSubPPtmpAAAM
        newXS_deffile("Wx::HtmlWinParser::GetWindow", XS_Wx__HtmlWinParser_GetWindow);
#endif
        newXS_deffile("Wx::HtmlWinParser::GetContainer", XS_Wx__HtmlWinParser_GetContainer);
        newXS_deffile("Wx::HtmlWinParser::OpenContainer", XS_Wx__HtmlWinParser_OpenContainer);
        newXS_deffile("Wx::HtmlWinParser::SetContainer", XS_Wx__HtmlWinParser_SetContainer);
        newXS_deffile("Wx::HtmlWinParser::CloseContainer", XS_Wx__HtmlWinParser_CloseContainer);
        newXS_deffile("Wx::HtmlWinParser::GetFontSize", XS_Wx__HtmlWinParser_GetFontSize);
        newXS_deffile("Wx::HtmlWinParser::SetFontSize", XS_Wx__HtmlWinParser_SetFontSize);
        newXS_deffile("Wx::HtmlWinParser::GetFontBold", XS_Wx__HtmlWinParser_GetFontBold);
        newXS_deffile("Wx::HtmlWinParser::SetFontBold", XS_Wx__HtmlWinParser_SetFontBold);
        newXS_deffile("Wx::HtmlWinParser::GetFontItalic", XS_Wx__HtmlWinParser_GetFontItalic);
        newXS_deffile("Wx::HtmlWinParser::SetFontItalic", XS_Wx__HtmlWinParser_SetFontItalic);
        newXS_deffile("Wx::HtmlWinParser::GetFontUnderlined", XS_Wx__HtmlWinParser_GetFontUnderlined);
        newXS_deffile("Wx::HtmlWinParser::SetFontUnderlined", XS_Wx__HtmlWinParser_SetFontUnderlined);
        newXS_deffile("Wx::HtmlWinParser::GetFontFixed", XS_Wx__HtmlWinParser_GetFontFixed);
        newXS_deffile("Wx::HtmlWinParser::SetFontFixed", XS_Wx__HtmlWinParser_SetFontFixed);
        newXS_deffile("Wx::HtmlWinParser::GetFontFace", XS_Wx__HtmlWinParser_GetFontFace);
        newXS_deffile("Wx::HtmlWinParser::SetFontFace", XS_Wx__HtmlWinParser_SetFontFace);
        newXS_deffile("Wx::HtmlWinParser::GetAlign", XS_Wx__HtmlWinParser_GetAlign);
        newXS_deffile("Wx::HtmlWinParser::SetAlign", XS_Wx__HtmlWinParser_SetAlign);
        newXS_deffile("Wx::HtmlWinParser::GetLinkColor", XS_Wx__HtmlWinParser_GetLinkColor);
        newXS_deffile("Wx::HtmlWinParser::SetLinkColor", XS_Wx__HtmlWinParser_SetLinkColor);
        newXS_deffile("Wx::HtmlWinParser::GetActualColor", XS_Wx__HtmlWinParser_GetActualColor);
        newXS_deffile("Wx::HtmlWinParser::SetActualColor", XS_Wx__HtmlWinParser_SetActualColor);
        newXS_deffile("Wx::HtmlWinParser::GetLink", XS_Wx__HtmlWinParser_GetLink);
        newXS_deffile("Wx::HtmlWinParser::SetLink", XS_Wx__HtmlWinParser_SetLink);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::HtmlWinParser::SetInputEncoding", XS_Wx__HtmlWinParser_SetInputEncoding);
        newXS_deffile("Wx::HtmlWinParser::GetInputEncoding", XS_Wx__HtmlWinParser_GetInputEncoding);
        newXS_deffile("Wx::HtmlWinParser::GetOutputEncoding", XS_Wx__HtmlWinParser_GetOutputEncoding);
        newXS_deffile("Wx::HtmlWinParser::GetEncodingConverter", XS_Wx__HtmlWinParser_GetEncodingConverter);
#endif
        newXS_deffile("Wx::HtmlWinParser::CreateCurrentFont", XS_Wx__HtmlWinParser_CreateCurrentFont);
        newXS_deffile("Wx::HtmlTagHandler::SetParser", XS_Wx__HtmlTagHandler_SetParser);
        newXS_deffile("Wx::HtmlTagHandler::GetSupportedTags", XS_Wx__HtmlTagHandler_GetSupportedTags);
        newXS_deffile("Wx::HtmlTagHandler::HandleTag", XS_Wx__HtmlTagHandler_HandleTag);
        newXS_deffile("Wx::PlHtmlTagHandler::new", XS_Wx__PlHtmlTagHandler_new);
        newXS_deffile("Wx::PlHtmlTagHandler::GetParser", XS_Wx__PlHtmlTagHandler_GetParser);
        newXS_deffile("Wx::PlHtmlWinTagHandler::new", XS_Wx__PlHtmlWinTagHandler_new);
        newXS_deffile("Wx::PlHtmlWinTagHandler::GetParser", XS_Wx__PlHtmlWinTagHandler_GetParser);
        newXS_deffile("Wx::HtmlTag::GetParent", XS_Wx__HtmlTag_GetParent);
        newXS_deffile("Wx::HtmlTag::GetFirstSibling", XS_Wx__HtmlTag_GetFirstSibling);
        newXS_deffile("Wx::HtmlTag::GetLastSibling", XS_Wx__HtmlTag_GetLastSibling);
        newXS_deffile("Wx::HtmlTag::GetChildren", XS_Wx__HtmlTag_GetChildren);
        newXS_deffile("Wx::HtmlTag::GetPreviousSibling", XS_Wx__HtmlTag_GetPreviousSibling);
        newXS_deffile("Wx::HtmlTag::GetNextSibling", XS_Wx__HtmlTag_GetNextSibling);
        newXS_deffile("Wx::HtmlTag::GetNextTag", XS_Wx__HtmlTag_GetNextTag);
        newXS_deffile("Wx::HtmlTag::GetName", XS_Wx__HtmlTag_GetName);
        newXS_deffile("Wx::HtmlTag::HasParam", XS_Wx__HtmlTag_HasParam);
        newXS_deffile("Wx::HtmlTag::GetParam", XS_Wx__HtmlTag_GetParam);
        newXS_deffile("Wx::HtmlTag::GetAllParams", XS_Wx__HtmlTag_GetAllParams);
        newXS_deffile("Wx::HtmlTag::HasEnding", XS_Wx__HtmlTag_HasEnding);
#if XSubPPtmpAAAO
        newXS_deffile("Wx::HtmlTag::GetBeginPos", XS_Wx__HtmlTag_GetBeginPos);
        newXS_deffile("Wx::HtmlTag::GetEndPos1", XS_Wx__HtmlTag_GetEndPos1);
        newXS_deffile("Wx::HtmlTag::GetEndPos2", XS_Wx__HtmlTag_GetEndPos2);
#endif
        newXS_deffile("Wx::HtmlTag::GetParamAsColour", XS_Wx__HtmlTag_GetParamAsColour);
        newXS_deffile("Wx::HtmlTag::GetParamAsInt", XS_Wx__HtmlTag_GetParamAsInt);
        newXS_deffile("Wx::HtmlCell::new", XS_Wx__HtmlCell_new);
        newXS_deffile("Wx::HtmlCell::Destroy", XS_Wx__HtmlCell_Destroy);
        newXS_deffile("Wx::HtmlCell::SetParent", XS_Wx__HtmlCell_SetParent);
        newXS_deffile("Wx::HtmlCell::GetParent", XS_Wx__HtmlCell_GetParent);
        newXS_deffile("Wx::HtmlCell::GetPosX", XS_Wx__HtmlCell_GetPosX);
        newXS_deffile("Wx::HtmlCell::GetPosY", XS_Wx__HtmlCell_GetPosY);
        newXS_deffile("Wx::HtmlCell::GetWidth", XS_Wx__HtmlCell_GetWidth);
        newXS_deffile("Wx::HtmlCell::GetHeight", XS_Wx__HtmlCell_GetHeight);
        newXS_deffile("Wx::HtmlCell::GetDescent", XS_Wx__HtmlCell_GetDescent);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::HtmlCell::IsFormattingCell", XS_Wx__HtmlCell_IsFormattingCell);
#endif
        newXS_deffile("Wx::HtmlCell::GetId", XS_Wx__HtmlCell_GetId);
        newXS_deffile("Wx::HtmlCell::SetId", XS_Wx__HtmlCell_SetId);
        newXS_deffile("Wx::HtmlCell::GetLink", XS_Wx__HtmlCell_GetLink);
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::HtmlCell::GetCursor", XS_Wx__HtmlCell_GetCursor);
#endif
        newXS_deffile("Wx::HtmlCell::GetNext", XS_Wx__HtmlCell_GetNext);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::HtmlCell::GetFirstChild", XS_Wx__HtmlCell_GetFirstChild);
#endif
        newXS_deffile("Wx::HtmlCell::SetPos", XS_Wx__HtmlCell_SetPos);
        newXS_deffile("Wx::HtmlCell::SetLink", XS_Wx__HtmlCell_SetLink);
        newXS_deffile("Wx::HtmlCell::SetNext", XS_Wx__HtmlCell_SetNext);
        newXS_deffile("Wx::HtmlCell::Layout", XS_Wx__HtmlCell_Layout);
        newXS_deffile("Wx::HtmlCell::SetCanLiveOnPagebreak", XS_Wx__HtmlCell_SetCanLiveOnPagebreak);
#if XSubPPtmpAAAS
        newXS_deffile("Wx::HtmlCell::IsLinebreakAllowed", XS_Wx__HtmlCell_IsLinebreakAllowed);
#endif
        newXS_deffile("Wx::HtmlCell::IsTerminalCell", XS_Wx__HtmlCell_IsTerminalCell);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::HtmlCell::FindCellByPos", XS_Wx__HtmlCell_FindCellByPos);
        newXS_deffile("Wx::HtmlCell::GetAbsPos", XS_Wx__HtmlCell_GetAbsPos);
        newXS_deffile("Wx::HtmlCell::GetFirstTerminal", XS_Wx__HtmlCell_GetFirstTerminal);
        newXS_deffile("Wx::HtmlCell::GetLastTerminal", XS_Wx__HtmlCell_GetLastTerminal);
        newXS_deffile("Wx::HtmlCell::GetDepth", XS_Wx__HtmlCell_GetDepth);
        newXS_deffile("Wx::HtmlCell::IsBefore", XS_Wx__HtmlCell_IsBefore);
        newXS_deffile("Wx::HtmlCell::ConvertToText", XS_Wx__HtmlCell_ConvertToText);
#endif
#if XSubPPtmpAAAU
        newXS_deffile("Wx::HtmlCell::FindCellByPos", XS_Wx__HtmlCell_FindCellByPos);
#endif
#if XSubPPtmpAAAV
        newXS_deffile("Wx::HtmlWordCell::SetPreviousWord", XS_Wx__HtmlWordCell_SetPreviousWord);
#endif
        newXS_deffile("Wx::HtmlContainerCell::new", XS_Wx__HtmlContainerCell_new);
        newXS_deffile("Wx::HtmlContainerCell::InsertCell", XS_Wx__HtmlContainerCell_InsertCell);
        newXS_deffile("Wx::HtmlContainerCell::SetAlignHor", XS_Wx__HtmlContainerCell_SetAlignHor);
        newXS_deffile("Wx::HtmlContainerCell::GetAlignHor", XS_Wx__HtmlContainerCell_GetAlignHor);
        newXS_deffile("Wx::HtmlContainerCell::SetAlignVer", XS_Wx__HtmlContainerCell_SetAlignVer);
        newXS_deffile("Wx::HtmlContainerCell::GetAlignVer", XS_Wx__HtmlContainerCell_GetAlignVer);
        newXS_deffile("Wx::HtmlContainerCell::SetIndent", XS_Wx__HtmlContainerCell_SetIndent);
        newXS_deffile("Wx::HtmlContainerCell::GetIndent", XS_Wx__HtmlContainerCell_GetIndent);
        newXS_deffile("Wx::HtmlContainerCell::GetIndentUnits", XS_Wx__HtmlContainerCell_GetIndentUnits);
        newXS_deffile("Wx::HtmlContainerCell::SetAlign", XS_Wx__HtmlContainerCell_SetAlign);
        newXS_deffile("Wx::HtmlContainerCell::SetWidthFloat", XS_Wx__HtmlContainerCell_SetWidthFloat);
        newXS_deffile("Wx::HtmlContainerCell::SetWidthFloatTag", XS_Wx__HtmlContainerCell_SetWidthFloatTag);
        newXS_deffile("Wx::HtmlContainerCell::SetMinHeight", XS_Wx__HtmlContainerCell_SetMinHeight);
        newXS_deffile("Wx::HtmlContainerCell::SetBackgroundColour", XS_Wx__HtmlContainerCell_SetBackgroundColour);
        newXS_deffile("Wx::HtmlContainerCell::GetBackgroundColour", XS_Wx__HtmlContainerCell_GetBackgroundColour);
        newXS_deffile("Wx::HtmlContainerCell::SetBorder", XS_Wx__HtmlContainerCell_SetBorder);
#if XSubPPtmpAAAW
        newXS_deffile("Wx::HtmlContainerCell::RemoveExtraSpacing", XS_Wx__HtmlContainerCell_RemoveExtraSpacing);
#endif
        newXS_deffile("Wx::HtmlColourCell::new", XS_Wx__HtmlColourCell_new);
        newXS_deffile("Wx::HtmlFontCell::new", XS_Wx__HtmlFontCell_new);
        newXS_deffile("Wx::HtmlWidgetCell::new", XS_Wx__HtmlWidgetCell_new);
#if XSubPPtmpAAAX
        newXS_deffile("Wx::HtmlListBox::Create", XS_Wx__HtmlListBox_Create);
        newXS_deffile("Wx::HtmlListBox::GetFileSystem", XS_Wx__HtmlListBox_GetFileSystem);
        newXS_deffile("Wx::PlHtmlListBox::newDefault", XS_Wx__PlHtmlListBox_newDefault);
        newXS_deffile("Wx::PlHtmlListBox::newFull", XS_Wx__PlHtmlListBox_newFull);
        newXS_deffile("Wx::PlHtmlListBox::new", XS_Wx__PlHtmlListBox_new);
#if XSubPPtmpAAAY
        newXS_deffile("Wx::SimpleHtmlListBox::newDefault", XS_Wx__SimpleHtmlListBox_newDefault);
        newXS_deffile("Wx::SimpleHtmlListBox::newFull", XS_Wx__SimpleHtmlListBox_newFull);
        newXS_deffile("Wx::SimpleHtmlListBox::Create", XS_Wx__SimpleHtmlListBox_Create);
        newXS_deffile("Wx::SimpleHtmlListBox::SetSelection", XS_Wx__SimpleHtmlListBox_SetSelection);
        newXS_deffile("Wx::SimpleHtmlListBox::GetSelection", XS_Wx__SimpleHtmlListBox_GetSelection);
        newXS_deffile("Wx::SimpleHtmlListBox::GetCount", XS_Wx__SimpleHtmlListBox_GetCount);
        newXS_deffile("Wx::SimpleHtmlListBox::GetString", XS_Wx__SimpleHtmlListBox_GetString);
        newXS_deffile("Wx::SimpleHtmlListBox::SetString", XS_Wx__SimpleHtmlListBox_SetString);
        newXS_deffile("Wx::SimpleHtmlListBox::Clear", XS_Wx__SimpleHtmlListBox_Clear);
        newXS_deffile("Wx::SimpleHtmlListBox::Delete", XS_Wx__SimpleHtmlListBox_Delete);
        newXS_deffile("Wx::SimpleHtmlListBox::AppendStrings", XS_Wx__SimpleHtmlListBox_AppendStrings);
        newXS_deffile("Wx::SimpleHtmlListBox::AppendString", XS_Wx__SimpleHtmlListBox_AppendString);
        newXS_deffile("Wx::SimpleHtmlListBox::AppendData", XS_Wx__SimpleHtmlListBox_AppendData);
        newXS_deffile("Wx::SimpleHtmlListBox::new", XS_Wx__SimpleHtmlListBox_new);
        newXS_deffile("Wx::SimpleHtmlListBox::Append", XS_Wx__SimpleHtmlListBox_Append);
#endif
#endif
        newXS_deffile("Wx::HtmlPrintout::new", XS_Wx__HtmlPrintout_new);
        newXS_deffile("Wx::HtmlPrintout::Destroy", XS_Wx__HtmlPrintout_Destroy);
        newXS_deffile("Wx::HtmlPrintout::SetHtmlText", XS_Wx__HtmlPrintout_SetHtmlText);
        newXS_deffile("Wx::HtmlPrintout::SetHtmlFile", XS_Wx__HtmlPrintout_SetHtmlFile);
        newXS_deffile("Wx::HtmlPrintout::SetHeader", XS_Wx__HtmlPrintout_SetHeader);
        newXS_deffile("Wx::HtmlPrintout::SetFooter", XS_Wx__HtmlPrintout_SetFooter);
        newXS_deffile("Wx::HtmlPrintout::SetStandardFonts", XS_Wx__HtmlPrintout_SetStandardFonts);
        newXS_deffile("Wx::HtmlPrintout::SetMargins", XS_Wx__HtmlPrintout_SetMargins);
        newXS_deffile("Wx::HtmlPrintout::OnPrintPage", XS_Wx__HtmlPrintout_OnPrintPage);
        newXS_deffile("Wx::HtmlPrintout::HasPage", XS_Wx__HtmlPrintout_HasPage);
        newXS_deffile("Wx::HtmlPrintout::OnBeginDocument", XS_Wx__HtmlPrintout_OnBeginDocument);
        newXS_deffile("Wx::HtmlPrintout::OnPreparePrinting", XS_Wx__HtmlPrintout_OnPreparePrinting);
        newXS_deffile("Wx::HtmlPrintout::CleanUpStatics", XS_Wx__HtmlPrintout_CleanUpStatics);
        newXS_deffile("Wx::HtmlPrintout::GetPageInfo", XS_Wx__HtmlPrintout_GetPageInfo);
        newXS_deffile("Wx::HtmlPrintout::SetFonts", XS_Wx__HtmlPrintout_SetFonts);

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#if XSubPPtmpAAAY
#endif
#endif
    {
        AV* isa = get_av( "Wx::HtmlPrintout::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Printout", 0 ) );
    } // blank line here is important


    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

